import { ChangeDetectorRef, EventEmitter, OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
import { DialogConfig } from './dialog.config';
/**
 * 对话框，依赖于 `weui-textarea`、`weui-slider`
 *
 * 关于 `input==='prompt'` 若干细节：
 *  + 对话框内放表单在weui的表现并不是很如意，因此，在对话框增加 `.weui-dialog__prompt` 样式类名，请自行针对性进行一些样式的覆盖，`ngx-dialog` 不提供任何样式的修正。
 *  + 对于录入型表单其校验机制全都是依赖于正则，默认情况下内置 `email`、`url` 两种表单类型的正则。
 */
export declare class DialogComponent implements OnDestroy {
    private DEF;
    private cdr;
    private _config;
    private observer;
    _shown: boolean;
    /**
     * 打开动画结束后回调（唯一参数：对话框实例对象）
     */
    readonly open: EventEmitter<DialogComponent>;
    /**
     * 关闭动画开始时回调（唯一参数：对话框实例对象）
     */
    readonly close: EventEmitter<DialogComponent>;
    container: any;
    _prompError: boolean;
    _promptData: any;
    /**
     * 对话框配置项
     */
    set config(value: DialogConfig);
    get config(): DialogConfig;
    constructor(DEF: DialogConfig, cdr: ChangeDetectorRef);
    private promptCheck;
    private setFocus;
    _chanage(): void;
    _keyup(event: KeyboardEvent): void;
    /**
     * 显示，组件载入页面后并不会显示，显示调用 `show()` 并订阅结果。
     *
     * @returns 当 `type==='prompt'` 时会多一 `result` 属性表示结果值
     */
    show(): Observable<any>;
    /**
     * 隐藏
     *
     * @param is_backdrop 是否从背景上点击
     */
    hide(is_backdrop?: boolean): void;
    _onSelect(menu?: any): boolean;
    ngOnDestroy(): void;
}
