import { __decorate, __metadata } from 'tslib';
import { Injectable, ɵɵdefineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, Host, NgModule } from '@angular/core';
import { InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: accordion.config.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionConfig {
    constructor() {
        /**
         * 是否可折叠，`false` 表示保持只有一个可折叠，`true` 表示所有都允许，默认：`false`
         */
        this.collapsible = false;
        /**
         * 自动展开第一次，默认：`true`
         */
        this.activeFirst = true;
        /**
         * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
         */
        this.animate = 'slide';
    }
}
AccordionConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ AccordionConfig.ɵprov = ɵɵdefineInjectable({ factory: function AccordionConfig_Factory() { return new AccordionConfig(); }, token: AccordionConfig, providedIn: "root" });
if (false) {
    /**
     * 是否可折叠，`false` 表示保持只有一个可折叠，`true` 表示所有都允许，默认：`false`
     * @type {?}
     */
    AccordionConfig.prototype.collapsible;
    /**
     * 自动展开第一次，默认：`true`
     * @type {?}
     */
    AccordionConfig.prototype.activeFirst;
    /**
     * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
     * @type {?}
     */
    AccordionConfig.prototype.animate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: accordion.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionComponent {
    /**
     * @param {?} config
     */
    constructor(config) {
        /**
         * 是否可折叠，`true` 表示同时所有都允许展开，`false` 表示同时只允许一个展开，默认：`false`
         */
        this.collapsible = false;
        /**
         * 自动展开第一次，默认：`true`
         */
        this.activeFirst = true;
        /**
         * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
         */
        this._animate = 'slide';
        /**
         * 展开时回调，参数为面板下标。
         */
        this.select = new EventEmitter();
        this.panels = [];
        Object.assign(this, config);
    }
    /**
     * @param {?} item
     * @return {?}
     */
    _add(item) {
        this.panels.push(item);
        if (this.panels.length === 1 && this.activeFirst) {
            item.active = true;
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    _remove(item) {
        this.panels.splice(this.panels.indexOf(item), 1);
    }
    /**
     * @param {?} item
     * @return {?}
     */
    _index(item) {
        return this.panels.indexOf(item);
    }
    /**
     * @param {?} cur
     * @return {?}
     */
    _closeOthers(cur) {
        if (this.collapsible) {
            return;
        }
        this.panels.forEach((/**
         * @param {?} panel
         * @return {?}
         */
        panel => {
            if (!panel.disabled && panel !== cur) {
                panel.active = false;
            }
        }));
    }
}
AccordionComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-accordion',
                exportAs: 'weuiAccordion',
                template: ` <ng-content></ng-content> `,
                host: {
                    '[attr.aria-multiselectable]': 'collapsible',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
AccordionComponent.ctorParameters = () => [
    { type: AccordionConfig }
];
AccordionComponent.propDecorators = {
    collapsible: [{ type: Input }],
    activeFirst: [{ type: Input }],
    _animate: [{ type: Input }],
    select: [{ type: Output }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], AccordionComponent.prototype, "collapsible", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], AccordionComponent.prototype, "activeFirst", void 0);
if (false) {
    /**
     * 是否可折叠，`true` 表示同时所有都允许展开，`false` 表示同时只允许一个展开，默认：`false`
     * @type {?}
     */
    AccordionComponent.prototype.collapsible;
    /**
     * 自动展开第一次，默认：`true`
     * @type {?}
     */
    AccordionComponent.prototype.activeFirst;
    /**
     * 动画类型，`none` 无动画，`slide` 滑动，默认：`slide`
     * @type {?}
     */
    AccordionComponent.prototype._animate;
    /**
     * 展开时回调，参数为面板下标。
     * @type {?}
     */
    AccordionComponent.prototype.select;
    /**
     * @type {?}
     * @private
     */
    AccordionComponent.prototype.panels;
}
class AccordionPanelComponent {
    /**
     * @param {?} accordion
     */
    constructor(accordion) {
        this.accordion = accordion;
        /**
         * 是否禁止
         */
        this.disabled = false;
        this._active = false;
    }
    /**
     * 是否展开
     * @return {?}
     */
    get active() {
        return this._active;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set active(value) {
        this._active = value;
        if (value) {
            this.accordion._closeOthers(this);
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.accordion._add(this);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.accordion._remove(this);
    }
    /**
     * @return {?}
     */
    _toggle() {
        if (!this.disabled) {
            this.active = !this.active;
            this.accordion.select.emit(this.accordion._index(this));
        }
    }
}
AccordionPanelComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-accordion-panel',
                exportAs: 'weuiAccordionPanel',
                template: `
    <div role="tab" (click)="_toggle()"><ng-content select="[heading]"></ng-content></div>
    <div role="tabpanel" class="weui-accordion-content"><ng-content></ng-content></div>
  `,
                host: {
                    '[class.weui-accordion-panel-disabled]': 'disabled',
                    '[class.weui-accordion-active]': 'active',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
AccordionPanelComponent.ctorParameters = () => [
    { type: AccordionComponent, decorators: [{ type: Host }] }
];
AccordionPanelComponent.propDecorators = {
    disabled: [{ type: Input }],
    active: [{ type: Input }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], AccordionPanelComponent.prototype, "disabled", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], AccordionPanelComponent.prototype, "active", null);
if (false) {
    /**
     * 是否禁止
     * @type {?}
     */
    AccordionPanelComponent.prototype.disabled;
    /**
     * @type {?}
     * @private
     */
    AccordionPanelComponent.prototype._active;
    /**
     * @type {?}
     * @protected
     */
    AccordionPanelComponent.prototype.accordion;
}

/**
 * @fileoverview added by tsickle
 * Generated from: accordion.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionModule {
}
AccordionModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [AccordionPanelComponent, AccordionComponent],
                exports: [AccordionPanelComponent, AccordionComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-accordion.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AccordionComponent, AccordionConfig, AccordionModule, AccordionPanelComponent };
//# sourceMappingURL=ngx-weui-accordion.js.map
