import { __decorate, __metadata } from 'tslib';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, NgModule } from '@angular/core';
import { genImageUrl, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: gallery.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 数据对象
 * @record
 */
function GalleryItem() { }
if (false) {
    /**
     * 远程网址
     * @type {?|undefined}
     */
    GalleryItem.prototype.url;
    /**
     * JavaScript File 对象
     * @type {?|undefined}
     */
    GalleryItem.prototype.file;
    /**
     * 文件标题
     * @type {?|undefined}
     */
    GalleryItem.prototype.title;
    /**
     * 是否允许删除，默认：`true`
     * @type {?|undefined}
     */
    GalleryItem.prototype.canDelete;
}
class GalleryComponent {
    constructor() {
        /**
         * 是否允许删除，默认：`true`
         */
        this.canDelete = true;
        /**
         * 删除回调
         */
        this.delete = new EventEmitter();
        /**
         * 隐藏回调
         */
        this.hide = new EventEmitter();
        /**
         * 标记是否显示，支持双向绑定
         */
        this.show = false;
        this.showChange = new EventEmitter();
        this._showd = false;
    }
    /**
     * 图片数据
     *
     * - 虽然支持传递数组，但并不支持在打开后切换图片。
     * @param {?} val
     * @return {?}
     */
    set imgs(val) {
        this.parseImgs(val);
    }
    /**
     * @return {?}
     */
    get _visibility() {
        return this.show ? 'show' : 'hide';
    }
    /**
     * @return {?}
     */
    _antStart() {
        if (this.show) {
            this._showd = this.show;
        }
    }
    /**
     * @return {?}
     */
    _antDone() {
        this._showd = this.show;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    _onDel(item) {
        if (this.canDelete) {
            this.delete.emit(item);
            this._onHide();
        }
        return false;
    }
    /**
     * @return {?}
     */
    _onHide() {
        this.show = false;
        this.showChange.emit(this.show);
        this.hide.emit();
    }
    /**
     * @private
     * @param {?} imgs
     * @return {?}
     */
    parseImgs(imgs) {
        if (Array.isArray(imgs)) {
            if (imgs.length > 0) {
                if (typeof imgs[0] === 'string') {
                    imgs = ((/** @type {?} */ (imgs))).map((/**
                     * @param {?} url
                     * @return {?}
                     */
                    (url) => {
                        return { url };
                    }));
                }
                else {
                    imgs = ((/** @type {?} */ (imgs))).map((/**
                     * @param {?} item
                     * @return {?}
                     */
                    (item) => {
                        if (item.file) {
                            item.url = genImageUrl(item.file);
                        }
                        return item;
                    }));
                }
            }
        }
        else {
            if (typeof imgs === 'string') {
                imgs = [{ url: imgs }];
            }
            else {
                /** @type {?} */
                const imgUrl = genImageUrl(imgs);
                if (imgUrl) {
                    imgs = [{ url: imgUrl }];
                }
            }
        }
        // todo: 永远只返回一个
        // 针对未来可能直接上下个
        this._imgs = imgs && ((/** @type {?} */ (imgs))).length > 0 ? imgs.slice(0, 1) : [];
    }
}
GalleryComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-gallery',
                exportAs: 'weuiGallery',
                template: "<div *ngIf=\"_imgs\" class=\"weui-galleries\">\n  <ng-template ngFor let-item [ngForOf]=\"_imgs\">\n    <div\n      class=\"weui-gallery\"\n      [ngStyle]=\"{ display: _showd ? 'block' : 'none' }\"\n      [@visibility]=\"_visibility\"\n      (@visibility.start)=\"_antStart()\"\n      (@visibility.done)=\"_antDone()\"\n      (click)=\"_onHide()\"\n    >\n      <span class=\"weui-gallery__img\" [ngStyle]=\"{ 'background-image': 'url(' + item?.url + ')' }\"></span>\n      <div class=\"weui-gallery__opr\" *ngIf=\"canDelete\">\n        <a href=\"#\" class=\"weui-gallery__del\" (click)=\"_onDel(item)\">\n          <i class=\"weui-icon-delete weui-icon_gallery-delete\"></i>\n        </a>\n      </div>\n    </div>\n  </ng-template>\n</div>\n",
                animations: [
                    trigger('visibility', [
                        state('show', style({ opacity: 1 })),
                        state('hide', style({ opacity: 0 })),
                        transition('hide <=> show', [animate(200)]),
                    ]),
                ],
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
GalleryComponent.propDecorators = {
    canDelete: [{ type: Input }],
    delete: [{ type: Output }],
    hide: [{ type: Output }],
    show: [{ type: Input }],
    showChange: [{ type: Output }],
    imgs: [{ type: Input }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], GalleryComponent.prototype, "canDelete", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], GalleryComponent.prototype, "show", void 0);
if (false) {
    /** @type {?} */
    GalleryComponent.prototype._imgs;
    /**
     * 是否允许删除，默认：`true`
     * @type {?}
     */
    GalleryComponent.prototype.canDelete;
    /**
     * 删除回调
     * @type {?}
     */
    GalleryComponent.prototype.delete;
    /**
     * 隐藏回调
     * @type {?}
     */
    GalleryComponent.prototype.hide;
    /**
     * 标记是否显示，支持双向绑定
     * @type {?}
     */
    GalleryComponent.prototype.show;
    /** @type {?} */
    GalleryComponent.prototype.showChange;
    /** @type {?} */
    GalleryComponent.prototype._showd;
}

/**
 * @fileoverview added by tsickle
 * Generated from: gallery.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GalleryModule {
}
GalleryModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [GalleryComponent],
                exports: [GalleryComponent],
                entryComponents: [GalleryComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-gallery.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { GalleryComponent, GalleryModule };
//# sourceMappingURL=ngx-weui-gallery.js.map
