import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, Output, NgModule } from '@angular/core';
import { InputBoolean } from 'ngx-weui/core';
import { Observable, Subscription } from 'rxjs';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: mask.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MaskComponent {
    /**
     * @param {?} cdr
     */
    constructor(cdr) {
        this.cdr = cdr;
        this._shown = false;
        /**
         * 点击是否允许关闭（默认：`false`）
         */
        this.backdrop = false;
        /**
         * 内容方向（默认：`vertical`）
         * + `top`: 顶部居中
         * + `bottom`: 底部居中
         * + `vertical-left`: 垂直居左
         * + `vertical`: 垂直居中
         * + `vertical-right`: 垂直居右
         * + `none`: 无
         */
        this.placement = 'vertical';
        /**
         * 内容背景色
         */
        this.bg = '';
        /**
         * 内容为Loading效果（默认：`false`）
         */
        this.loading = false;
        /**
         * 关闭回调
         */
        this.close = new EventEmitter();
    }
    /**
     * 显示，并返回一个Observable
     * @return {?}
     */
    show() {
        setTimeout((/**
         * @return {?}
         */
        () => {
            this._shown = true;
            this.cdr.detectChanges();
        }));
        return new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        (observer) => {
            this.observer = observer;
        }));
    }
    /**
     * 隐藏
     *
     * @param {?=} is_backdrop 是否手动点击关闭（默认：false）
     * @return {?}
     */
    hide(is_backdrop = false) {
        if (is_backdrop === true && this.backdrop === false) {
            return;
        }
        this._shown = false;
        this.cdr.detectChanges();
        this.close.emit();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.observer && this.observer instanceof Subscription) {
            ((/** @type {?} */ (this.observer))).unsubscribe();
        }
    }
}
MaskComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-mask',
                exportAs: 'weuiMask',
                template: "<div class=\"weui-mask\" [ngClass]=\"{ 'weui-mask__visible': _shown }\" (click)=\"hide(true)\">\n  <div class=\"weui-mask__content\" [ngClass]=\"placement !== 'none' ? 'weui-mask__' + placement : ''\">\n    <div [ngStyle]=\"{ 'background-color': bg }\">\n      <div *ngIf=\"loading\"><i class=\"weui-loading weui-icon_toast\"></i></div>\n      <ng-content></ng-content>\n    </div>\n  </div>\n</div>\n",
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
MaskComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
MaskComponent.propDecorators = {
    backdrop: [{ type: Input }],
    placement: [{ type: Input }],
    bg: [{ type: Input }],
    loading: [{ type: Input }],
    close: [{ type: Output }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], MaskComponent.prototype, "backdrop", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Object)
], MaskComponent.prototype, "loading", void 0);
if (false) {
    /**
     * @type {?}
     * @private
     */
    MaskComponent.prototype.observer;
    /** @type {?} */
    MaskComponent.prototype._shown;
    /**
     * 点击是否允许关闭（默认：`false`）
     * @type {?}
     */
    MaskComponent.prototype.backdrop;
    /**
     * 内容方向（默认：`vertical`）
     * + `top`: 顶部居中
     * + `bottom`: 底部居中
     * + `vertical-left`: 垂直居左
     * + `vertical`: 垂直居中
     * + `vertical-right`: 垂直居右
     * + `none`: 无
     * @type {?}
     */
    MaskComponent.prototype.placement;
    /**
     * 内容背景色
     * @type {?}
     */
    MaskComponent.prototype.bg;
    /**
     * 内容为Loading效果（默认：`false`）
     * @type {?}
     */
    MaskComponent.prototype.loading;
    /**
     * 关闭回调
     * @type {?}
     */
    MaskComponent.prototype.close;
    /**
     * @type {?}
     * @private
     */
    MaskComponent.prototype.cdr;
}

/**
 * @fileoverview added by tsickle
 * Generated from: mask.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MaskModule {
}
MaskModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [MaskComponent],
                exports: [MaskComponent],
                entryComponents: [MaskComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-mask.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { MaskComponent, MaskModule };
//# sourceMappingURL=ngx-weui-mask.js.map
