import { __decorate, __metadata } from 'tslib';
import { Injectable, ɵɵdefineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, ViewChild, NgModule } from '@angular/core';
import { InputNumber } from 'ngx-weui/core';
import { Subject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.config.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchBarConfig {
    constructor() {
        /**
         * 占位符，默认：`搜索`
         */
        this.placeholder = '搜索';
        /**
         * 取消按键文字，默认：`取消`
         */
        this.cancelText = '取消';
        /**
         * 去抖时长（单位：ms），默认：`300`
         */
        this.debounceTime = 300;
    }
}
SearchBarConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ SearchBarConfig.ɵprov = ɵɵdefineInjectable({ factory: function SearchBarConfig_Factory() { return new SearchBarConfig(); }, token: SearchBarConfig, providedIn: "root" });
if (false) {
    /**
     * 占位符，默认：`搜索`
     * @type {?}
     */
    SearchBarConfig.prototype.placeholder;
    /**
     * 取消按键文字，默认：`取消`
     * @type {?}
     */
    SearchBarConfig.prototype.cancelText;
    /**
     * 去抖时长（单位：ms），默认：`300`
     * @type {?}
     */
    SearchBarConfig.prototype.debounceTime;
}

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchBarComponent {
    /**
     * @param {?} DEF
     */
    constructor(DEF) {
        this._q = '';
        /**
         * 搜索回调
         */
        this.search = new EventEmitter();
        /**
         * 取消回调
         */
        this.cancel = new EventEmitter();
        /**
         * 清空回调
         */
        this.clear = new EventEmitter();
        /**
         * 提交回调（指的是键盘回车后）
         */
        this.submit = new EventEmitter();
        this._focus = false;
        this._subject = new Subject();
        Object.assign(this, DEF);
    }
    /**
     * @param {?} _value
     * @return {?}
     */
    set value(_value) {
        this._q = _value;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._sub = this._subject.pipe(debounceTime(this.debounceTime), distinctUntilChanged()).subscribe((/**
         * @param {?} q
         * @return {?}
         */
        (q) => {
            this.search.emit(q);
        }));
    }
    /**
     * @return {?}
     */
    _doFocus() {
        this._term.nativeElement.focus();
    }
    /**
     * @return {?}
     */
    _onBlur() {
        if (this._q === '') {
            this._focus = false;
        }
    }
    /**
     * @return {?}
     */
    _onSearch() {
        this._subject.next(this._q);
    }
    /**
     * @return {?}
     */
    _onCancel() {
        this._q = '';
        this._onBlur();
        this._subject.next('');
        this.cancel.emit();
    }
    /**
     * @return {?}
     */
    _onClear() {
        this._q = '';
        this._doFocus();
        this._subject.next('');
        this.clear.emit();
    }
    /**
     * @param {?} e
     * @return {?}
     */
    _onSubmit(e) {
        e.preventDefault();
        e.stopPropagation();
        this._subject.next(this._q);
        this.submit.emit(this._q);
        return false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._sub) {
            this._sub.unsubscribe();
        }
    }
}
SearchBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-searchbar',
                exportAs: 'weuiSearchbar',
                template: "<form class=\"weui-search-bar__form\" (ngSubmit)=\"_onSubmit($event)\">\n  <div class=\"weui-search-bar__box\">\n    <i class=\"weui-icon-search\"></i>\n    <input\n      #term\n      type=\"search\"\n      autocomplete=\"off\"\n      name=\"q\"\n      class=\"weui-search-bar__input\"\n      [placeholder]=\"placeholder\"\n      [(ngModel)]=\"_q\"\n      (ngModelChange)=\"_onSearch()\"\n      (focus)=\"_focus = true\"\n      (blur)=\"_onBlur()\"\n    />\n    <a href=\"javascript:\" class=\"weui-icon-clear\" (click)=\"_onClear()\"></a>\n  </div>\n  <label class=\"weui-search-bar__label\" (click)=\"_doFocus()\">\n    <i class=\"weui-icon-search\"></i>\n    <span>{{ placeholder }}</span>\n  </label>\n</form>\n<a class=\"weui-search-bar__cancel-btn\" (click)=\"_onCancel()\">{{ cancelText }}</a>\n",
                host: {
                    '[class.weui-search-bar]': `true`,
                    '[class.weui-search-bar_focusing]': `_focus`,
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
SearchBarComponent.ctorParameters = () => [
    { type: SearchBarConfig }
];
SearchBarComponent.propDecorators = {
    placeholder: [{ type: Input }],
    cancelText: [{ type: Input }],
    debounceTime: [{ type: Input }],
    search: [{ type: Output }],
    cancel: [{ type: Output }],
    clear: [{ type: Output }],
    submit: [{ type: Output }],
    _term: [{ type: ViewChild, args: ['term', { static: true },] }],
    value: [{ type: Input }]
};
__decorate([
    InputNumber(),
    __metadata("design:type", Number)
], SearchBarComponent.prototype, "debounceTime", void 0);
if (false) {
    /** @type {?} */
    SearchBarComponent.prototype._q;
    /**
     * 占位符，默认：`搜索`
     * @type {?}
     */
    SearchBarComponent.prototype.placeholder;
    /**
     * 取消按键文字，默认：`取消`
     * @type {?}
     */
    SearchBarComponent.prototype.cancelText;
    /**
     * 去抖时长（单位：ms），默认：`300`
     * @type {?}
     */
    SearchBarComponent.prototype.debounceTime;
    /**
     * 搜索回调
     * @type {?}
     */
    SearchBarComponent.prototype.search;
    /**
     * 取消回调
     * @type {?}
     */
    SearchBarComponent.prototype.cancel;
    /**
     * 清空回调
     * @type {?}
     */
    SearchBarComponent.prototype.clear;
    /**
     * 提交回调（指的是键盘回车后）
     * @type {?}
     */
    SearchBarComponent.prototype.submit;
    /** @type {?} */
    SearchBarComponent.prototype._focus;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._term;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._sub;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._subject;
}

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchBarModule {
}
SearchBarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [SearchBarComponent],
                exports: [SearchBarComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-searchbar.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SearchBarComponent, SearchBarConfig, SearchBarModule };
//# sourceMappingURL=ngx-weui-searchbar.js.map
