import { __decorate, __metadata } from 'tslib';
import { Injectable, ɵɵdefineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Inject, Input, Output, ViewChild, ChangeDetectorRef, ElementRef, ContentChildren, Directive, NgModule } from '@angular/core';
import { isIOS, InputBoolean } from 'ngx-weui/core';
import { DOCUMENT, CommonModule } from '@angular/common';
import { Subject } from 'rxjs';

/**
 * @fileoverview added by tsickle
 * Generated from: sidebar.config.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarConfig {
    constructor() {
        /**
         * 位置方向，默认：`left`
         */
        this.position = 'left';
        /**
         * 类型，默认：`slide`
         * - over: 不覆盖
         * - slide：侧边移动
         */
        this.mode = 'slide';
        /**
         * 允许点击背景关闭，默认：`true`
         */
        this.backdrop = true;
    }
}
SidebarConfig.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ SidebarConfig.ɵprov = ɵɵdefineInjectable({ factory: function SidebarConfig_Factory() { return new SidebarConfig(); }, token: SidebarConfig, providedIn: "root" });
if (false) {
    /**
     * 位置方向，默认：`left`
     * @type {?}
     */
    SidebarConfig.prototype.position;
    /**
     * 类型，默认：`slide`
     * - over: 不覆盖
     * - slide：侧边移动
     * @type {?}
     */
    SidebarConfig.prototype.mode;
    /**
     * 允许点击背景关闭，默认：`true`
     * @type {?}
     */
    SidebarConfig.prototype.backdrop;
}

/**
 * @fileoverview added by tsickle
 * Generated from: sidebar.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarService {
    constructor() {
        this._openObserver = new Subject();
        this._closeObserver = new Subject();
    }
    /**
     * @return {?}
     */
    open() {
        this._openObserver.next();
    }
    /**
     * @return {?}
     */
    close() {
        this._closeObserver.next();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    onOpen(fn) {
        return this._openObserver.subscribe(fn);
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    onClose(fn) {
        return this._closeObserver.subscribe(fn);
    }
}
SidebarService.decorators = [
    { type: Injectable }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    SidebarService.prototype._openObserver;
    /**
     * @type {?}
     * @private
     */
    SidebarService.prototype._closeObserver;
}

/**
 * @fileoverview added by tsickle
 * Generated from: sidebar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 侧边栏
 */
class SidebarComponent {
    /**
     * @param {?} _sidebarService
     * @param {?} config
     * @param {?} doc
     */
    constructor(_sidebarService, config, doc) {
        this._sidebarService = _sidebarService;
        this.doc = doc;
        /**
         * 状态，true表示打开，false表示关闭
         */
        this.status = false;
        this.statusChange = new EventEmitter();
        /**
         * 位置方向，默认：`left`
         */
        this.position = 'left';
        /**
         * 类型，默认：`slide`
         * - over: 不覆盖
         * - slide：侧边移动
         */
        this.mode = 'slide';
        /**
         * 允许点击背景关闭，默认：`true`
         */
        this.backdrop = true;
        /**
         * 打开前回调
         */
        this.openStart = new EventEmitter();
        /**
         * 打开后回调
         */
        this.opened = new EventEmitter();
        /**
         * 关闭前回调
         */
        this.closeStart = new EventEmitter();
        /**
         * 关闭后回调
         */
        this.closed = new EventEmitter();
        /**
         * 模式变更通知
         */
        this.modeChange = new EventEmitter();
        /**
         * 位置变更通知
         */
        this.positionChange = new EventEmitter();
        this._rerender = new EventEmitter();
        this._clickEvent = 'click';
        this._onClickOutsideAttached = false;
        this._anting = false;
        Object.assign(this, config);
        if (isIOS() && 'ontouchstart' in window) {
            this._clickEvent = 'touchstart';
        }
        this.open = this.open.bind(this);
        this.close = this.close.bind(this);
        this._onClickOutside = this._onClickOutside.bind(this);
        this._openSub = this._sidebarService.onOpen(this.open);
        this._closeSub = this._sidebarService.onClose(this.close);
    }
    /**
     * 获取侧边栏容器高度
     * @return {?}
     */
    get _height() {
        return this._elSidebar.nativeElement ? this._elSidebar.nativeElement.offsetHeight : 0;
    }
    /**
     * 获取侧边栏容器宽度
     * @return {?}
     */
    get _width() {
        return this._elSidebar.nativeElement ? this._elSidebar.nativeElement.offsetWidth : 0;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes.status && !this._anting) {
            if (changes.status.currentValue) {
                this.open();
            }
            else {
                this.close();
            }
            if (changes.status.firstChange) {
                this._anting = false;
            }
        }
        if (changes.mode) {
            this.modeChange.emit(changes.mode.currentValue);
        }
        if (changes.position) {
            this.positionChange.emit(changes.position.currentValue);
        }
        if (changes.backdrop) {
            this._initCloseListeners();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroyCloseListeners();
        if (this._openSub) {
            this._openSub.unsubscribe();
        }
        if (this._closeSub) {
            this._closeSub.unsubscribe();
        }
    }
    /**
     * 打开侧边栏
     * @return {?}
     */
    open() {
        this._anting = true;
        this.status = true;
        this.statusChange.emit(true);
        this.openStart.emit();
        this.closeAnt();
    }
    /**
     * 关闭侧边栏
     * @return {?}
     */
    close() {
        this._anting = true;
        this.status = false;
        this.statusChange.emit(false);
        this.closeStart.emit();
        this.closeAnt();
    }
    /**
     * 手动触发容器的重新渲染
     * @return {?}
     */
    _triggerRerender() {
        this._rerender.emit();
    }
    /**
     * @return {?}
     */
    _getStyle() {
        /** @type {?} */
        let transformStyle = 'none';
        /** @type {?} */
        const marginStyle = {};
        /** @type {?} */
        const isSlideMode = this.mode === 'slide';
        if (!this.status || isSlideMode) {
            transformStyle = `translate${this.position === 'left' || this.position === 'right' ? 'X' : 'Y'}`;
            /** @type {?} */
            const isLeftOrTop = this.position === 'left' || this.position === 'top';
            /** @type {?} */
            const translateAmt = `${isLeftOrTop ? '-' : ''}100%`;
            transformStyle += `(${translateAmt})`;
        }
        return (/** @type {?} */ (Object.assign(Object.assign({}, marginStyle), { webkitTransform: transformStyle, transform: transformStyle })));
    }
    /**
     * @private
     * @return {?}
     */
    closeAnt() {
        setTimeout((/**
         * @return {?}
         */
        () => {
            this._anting = false;
            if (this.status) {
                this._initCloseListeners();
                this.opened.emit();
            }
            else {
                this._destroyCloseListeners();
                this.closed.emit();
            }
        }), 300);
    }
    /**
     * @private
     * @return {?}
     */
    _initCloseListeners() {
        if (this.status && this.backdrop) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                if (this.backdrop && !this._onClickOutsideAttached) {
                    this.doc.addEventListener(this._clickEvent, this._onClickOutside, false);
                    this._onClickOutsideAttached = true;
                }
            }));
        }
    }
    /**
     * @private
     * @return {?}
     */
    _destroyCloseListeners() {
        if (this._onClickOutsideAttached) {
            this.doc.removeEventListener(this._clickEvent, this._onClickOutside, false);
            this._onClickOutsideAttached = false;
        }
    }
    /**
     * @private
     * @param {?} e
     * @return {?}
     */
    _onClickOutside(e) {
        if (this._onClickOutsideAttached && this._elSidebar && !this._elSidebar.nativeElement.contains((/** @type {?} */ (e.target)))) {
            this.close();
        }
    }
}
SidebarComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-sidebar',
                exportAs: 'weuiSidebar',
                template: "<aside\n  #sidebar\n  role=\"complementary\"\n  [attr.aria-hidden]=\"!status\"\n  [attr.aria-label]=\"ariaLabel\"\n  class=\"weui-sidebar weui-sidebar__{{ status ? 'opened' : 'closed' }} weui-sidebar__{{ position }} weui-sidebar__{{\n    mode\n  }}\"\n  [class.weui-sidebar__inert]=\"!status\"\n  [ngClass]=\"sidebarClass\"\n  [ngStyle]=\"_getStyle()\"\n>\n  <ng-content></ng-content>\n</aside>\n",
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
SidebarComponent.ctorParameters = () => [
    { type: SidebarService },
    { type: SidebarConfig },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
SidebarComponent.propDecorators = {
    status: [{ type: Input }],
    statusChange: [{ type: Output }],
    position: [{ type: Input }],
    mode: [{ type: Input }],
    backdrop: [{ type: Input }],
    sidebarClass: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    openStart: [{ type: Output }],
    opened: [{ type: Output }],
    closeStart: [{ type: Output }],
    closed: [{ type: Output }],
    modeChange: [{ type: Output }],
    positionChange: [{ type: Output }],
    _rerender: [{ type: Output }],
    _elSidebar: [{ type: ViewChild, args: ['sidebar', { static: true },] }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], SidebarComponent.prototype, "status", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], SidebarComponent.prototype, "backdrop", void 0);
if (false) {
    /**
     * 状态，true表示打开，false表示关闭
     * @type {?}
     */
    SidebarComponent.prototype.status;
    /** @type {?} */
    SidebarComponent.prototype.statusChange;
    /**
     * 位置方向，默认：`left`
     * @type {?}
     */
    SidebarComponent.prototype.position;
    /**
     * 类型，默认：`slide`
     * - over: 不覆盖
     * - slide：侧边移动
     * @type {?}
     */
    SidebarComponent.prototype.mode;
    /**
     * 允许点击背景关闭，默认：`true`
     * @type {?}
     */
    SidebarComponent.prototype.backdrop;
    /**
     * 自定义CLSS
     * @type {?}
     */
    SidebarComponent.prototype.sidebarClass;
    /**
     * 辅助设备标识
     * @type {?}
     */
    SidebarComponent.prototype.ariaLabel;
    /**
     * 打开前回调
     * @type {?}
     */
    SidebarComponent.prototype.openStart;
    /**
     * 打开后回调
     * @type {?}
     */
    SidebarComponent.prototype.opened;
    /**
     * 关闭前回调
     * @type {?}
     */
    SidebarComponent.prototype.closeStart;
    /**
     * 关闭后回调
     * @type {?}
     */
    SidebarComponent.prototype.closed;
    /**
     * 模式变更通知
     * @type {?}
     */
    SidebarComponent.prototype.modeChange;
    /**
     * 位置变更通知
     * @type {?}
     */
    SidebarComponent.prototype.positionChange;
    /** @type {?} */
    SidebarComponent.prototype._rerender;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._elSidebar;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._openSub;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._closeSub;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._clickEvent;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._onClickOutsideAttached;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._anting;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype._sidebarService;
    /**
     * @type {?}
     * @private
     */
    SidebarComponent.prototype.doc;
}

/**
 * @fileoverview added by tsickle
 * Generated from: sidebar-container.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 侧边栏容器
 */
class SidebarContainerComponent {
    /**
     * @param {?} _ref
     * @param {?} _el
     */
    constructor(_ref, _el) {
        this._ref = _ref;
        this._el = _el;
        this._showBackdrop = false;
        this._showBackdropChange = new EventEmitter();
        this.orgOverflowX = '';
    }
    /**
     * @private
     * @return {?}
     */
    get body() {
        return (/** @type {?} */ (document.querySelector('body')));
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this._onToggle();
        this._subscribe();
        this._sidebars.changes.subscribe((/**
         * @return {?}
         */
        () => {
            this._unsubscribe();
            this._subscribe();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes._showBackdrop) {
            this._showBackdropChange.emit(changes._showBackdrop.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.orgOverflowX = (/** @type {?} */ (this.body.style.overflowX));
        this.body.style.overflowX = 'hidden';
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._unsubscribe();
        this.body.style.overflowX = this.orgOverflowX;
    }
    /**
     * @return {?}
     */
    _getStyles() {
        if (this._sidebars) {
            this._sidebars.forEach((/**
             * @param {?} sidebar
             * @return {?}
             */
            (sidebar) => {
                if (!sidebar) {
                    return;
                }
                if (sidebar.mode === 'slide') {
                    /** @type {?} */
                    let transformStyle = null;
                    if (sidebar.status) {
                        /** @type {?} */
                        const isLeftOrTop = sidebar.position === 'left' || sidebar.position === 'top';
                        /** @type {?} */
                        const isLeftOrRight = sidebar.position === 'left' || sidebar.position === 'right';
                        /** @type {?} */
                        const transformDir = isLeftOrRight ? 'X' : 'Y';
                        /** @type {?} */
                        const transformAmt = `${isLeftOrTop ? '' : '-'}${isLeftOrRight ? sidebar._width : sidebar._height}`;
                        transformStyle = `translate${transformDir}(${transformAmt}px)`;
                    }
                    this._el.nativeElement.style.transform = transformStyle;
                }
            }));
        }
        return (/** @type {?} */ ({
            margin: `0px 0px 0px 0px`,
        }));
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    _onBackdropClicked($event) {
        $event.preventDefault();
        $event.stopPropagation();
        this._sidebars.forEach((/**
         * @param {?} sidebar
         * @return {?}
         */
        (sidebar) => {
            if (sidebar.status && sidebar.backdrop) {
                sidebar.close();
            }
        }));
        return false;
    }
    /**
     * @private
     * @return {?}
     */
    _subscribe() {
        if (this._sidebars) {
            this._sidebars.forEach((/**
             * @param {?} sidebar
             * @return {?}
             */
            (sidebar) => {
                if (!sidebar) {
                    return;
                }
                sidebar.openStart.subscribe((/**
                 * @return {?}
                 */
                () => this._onToggle()));
                sidebar.opened.subscribe((/**
                 * @return {?}
                 */
                () => this._markForCheck()));
                sidebar.closeStart.subscribe((/**
                 * @return {?}
                 */
                () => this._onToggle()));
                sidebar.closed.subscribe((/**
                 * @return {?}
                 */
                () => this._markForCheck()));
                sidebar.modeChange.subscribe((/**
                 * @return {?}
                 */
                () => this._markForCheck()));
                sidebar.positionChange.subscribe((/**
                 * @return {?}
                 */
                () => this._markForCheck()));
                sidebar._rerender.subscribe((/**
                 * @return {?}
                 */
                () => this._markForCheck()));
            }));
        }
    }
    /**
     * @private
     * @return {?}
     */
    _unsubscribe() {
        if (this._sidebars) {
            this._sidebars.forEach((/**
             * @param {?} sidebar
             * @return {?}
             */
            (sidebar) => {
                if (!sidebar) {
                    return;
                }
                sidebar.openStart.unsubscribe();
                sidebar.opened.unsubscribe();
                sidebar.closeStart.unsubscribe();
                sidebar.closed.unsubscribe();
                sidebar.modeChange.unsubscribe();
                sidebar.positionChange.unsubscribe();
                sidebar._rerender.unsubscribe();
            }));
        }
    }
    /**
     * 状态变更时重新计算样式
     * @private
     * @return {?}
     */
    _markForCheck() {
        this._ref.markForCheck();
    }
    /**
     * @private
     * @return {?}
     */
    _onToggle() {
        if (this._sidebars) {
            /** @type {?} */
            let hasOpen = false;
            /** @type {?} */
            const _sidebars = this._sidebars.toArray();
            // tslint:disable-next-line: prefer-for-of
            for (let i = 0; i < _sidebars.length; i++) {
                /** @type {?} */
                const sidebar = _sidebars[i];
                if (sidebar.status) {
                    hasOpen = true;
                    break;
                }
            }
            this._showBackdrop = hasOpen;
            this._showBackdropChange.emit(hasOpen);
        }
        this._markForCheck();
    }
}
SidebarContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-sidebar-container',
                exportAs: 'weuiSidebarContainer',
                template: "<ng-content select=\"weui-sidebar\"></ng-content>\n<div *ngIf=\"_showBackdrop\" aria-hidden=\"true\" class=\"weui-mask\" (click)=\"_onBackdropClicked($event)\"></div>\n<div class=\"weui-sidebar__content\" [ngStyle]=\"_getStyles()\">\n  <ng-content></ng-content>\n</div>\n",
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
SidebarContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
SidebarContainerComponent.propDecorators = {
    _sidebars: [{ type: ContentChildren, args: [SidebarComponent,] }],
    _showBackdrop: [{ type: Input }],
    _showBackdropChange: [{ type: Output }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], SidebarContainerComponent.prototype, "_showBackdrop", void 0);
if (false) {
    /** @type {?} */
    SidebarContainerComponent.prototype._sidebars;
    /** @type {?} */
    SidebarContainerComponent.prototype._showBackdrop;
    /** @type {?} */
    SidebarContainerComponent.prototype._showBackdropChange;
    /**
     * @type {?}
     * @private
     */
    SidebarContainerComponent.prototype.orgOverflowX;
    /**
     * @type {?}
     * @private
     */
    SidebarContainerComponent.prototype._ref;
    /**
     * @type {?}
     * @private
     */
    SidebarContainerComponent.prototype._el;
}

/**
 * @fileoverview added by tsickle
 * Generated from: close.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 关闭侧边栏指令
 */
class CloseSidebarDirective {
    /**
     * @param {?} _sidebarService
     */
    constructor(_sidebarService) {
        this._sidebarService = _sidebarService;
    }
    /**
     * @return {?}
     */
    _onClick() {
        this._sidebarService.close();
    }
}
CloseSidebarDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[closeSidebar]',
                exportAs: 'weuiCloseSidebar',
                host: {
                    '(click)': '_onClick()',
                },
            },] }
];
/** @nocollapse */
CloseSidebarDirective.ctorParameters = () => [
    { type: SidebarService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    CloseSidebarDirective.prototype._sidebarService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: sidebar.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COMPONENTS = [SidebarContainerComponent, SidebarComponent, CloseSidebarDirective];
class SidebarModule {
}
SidebarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: COMPONENTS,
                exports: COMPONENTS,
                providers: [SidebarService],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-sidebar.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { CloseSidebarDirective, SidebarComponent, SidebarConfig, SidebarContainerComponent, SidebarModule, SidebarService };
//# sourceMappingURL=ngx-weui-sidebar.js.map
