import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Component, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, Input, Output, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { InputNumber, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: stepper.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Stepper 步进器，支持 `[(ngModel)]`
 */
class StepperComponent {
    /**
     * @param {?} cdr
     */
    constructor(cdr) {
        this.cdr = cdr;
        this.onChange = Function.prototype;
        // private onTouched: any = Function.prototype;
        this._step = 1;
        this._precisionStep = 0;
        this._precisionFactor = 1;
        this._disabledMinus = false;
        this._disabledPlus = false;
        /**
         * 最小值
         */
        this.min = -Infinity;
        /**
         * 最大值
         */
        this.max = Infinity;
        /**
         * 禁用
         */
        this.disabled = false;
        /**
         * 变更时回调
         */
        this.change = new EventEmitter();
    }
    /**
     * 步长，可以为小数
     * @return {?}
     */
    get step() {
        return this._step;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set step(value) {
        this._step = value;
        /** @type {?} */
        const stepString = value.toString();
        if (stepString.indexOf('e-') >= 0) {
            this._precisionStep = parseInt(stepString.slice(stepString.indexOf('e-')), 10);
        }
        if (stepString.indexOf('.') >= 0) {
            this._precisionStep = stepString.length - stepString.indexOf('.') - 1;
        }
        this._precisionFactor = Math.pow(10, this._precisionStep);
    }
    /**
     * @return {?}
     */
    get value() {
        return this._value;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set value(value) {
        if (isNaN(value) || value === this.value) {
            return;
        }
        value = +value;
        if (value > this.max) {
            this._value = this.max;
            this.onChange(this.max);
        }
        else if (value < this.min) {
            this._value = this.min;
            this.onChange(this.min);
        }
        else {
            this._value = value;
        }
        this._checkDisabled();
        this.cdr.detectChanges();
    }
    /**
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    _checkDisabled() {
        (/** @type {?} */ (this))._disabledPlus = (/** @type {?} */ (this)).disabled || !((/** @type {?} */ (this)).value + (/** @type {?} */ (this)).step <= (/** @type {?} */ (this)).max);
        (/** @type {?} */ (this))._disabledMinus = (/** @type {?} */ (this)).disabled || !((/** @type {?} */ (this)).value - (/** @type {?} */ (this)).step >= (/** @type {?} */ (this)).min);
        return (/** @type {?} */ (this));
    }
    /**
     * @return {?}
     */
    _notify() {
        this.change.emit(this.value);
        this.onChange(this.value);
    }
    /**
     * @return {?}
     */
    _plus() {
        if (this.value === undefined) {
            this.value = this.max || 0;
        }
        this._checkDisabled();
        if (this._disabledPlus) {
            return;
        }
        this.value = this._toPrecisionAsStep((this._precisionFactor * this.value + this._precisionFactor * this.step) / this._precisionFactor);
        this._checkDisabled()._notify();
    }
    /**
     * @return {?}
     */
    _minus() {
        if (this.value === undefined) {
            this.value = this.min || 0;
        }
        this._checkDisabled();
        if (this._disabledMinus) {
            return;
        }
        this.value = this._toPrecisionAsStep((this._precisionFactor * this.value - this._precisionFactor * this.step) / this._precisionFactor);
        this._checkDisabled()._notify();
    }
    /**
     * @return {?}
     */
    _blur() {
        /** @type {?} */
        const el = this._inputNumber.nativeElement;
        this.value = +el.value;
        el.value = this.value.toString();
        this._checkDisabled()._notify();
    }
    /**
     * @param {?} num
     * @return {?}
     */
    _toPrecisionAsStep(num) {
        if (isNaN(num) || num === '') {
            return num;
        }
        return Number(Number(num).toFixed(this._precisionStep));
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.value = value;
        this._checkDisabled();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} _fn
     * @return {?}
     */
    registerOnTouched(_fn) {
        // this.onTouched = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
}
StepperComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-stepper',
                exportAs: 'weuiStepper',
                template: "<span class=\"minus\" [ngClass]=\"{ disabled: _disabledMinus }\" (click)=\"_minus()\"><em>-</em></span>\n<div class=\"input\">\n  <input\n    type=\"tel\"\n    #inputNumber\n    [(ngModel)]=\"value\"\n    (blur)=\"_blur()\"\n    [disabled]=\"disabled\"\n    [attr.min]=\"min\"\n    [attr.max]=\"max\"\n    [attr.step]=\"_step\"\n    autocomplete=\"off\"\n  />\n</div>\n<span class=\"plus\" [ngClass]=\"{ disabled: _disabledPlus }\" (click)=\"_plus()\"><em>+</em></span>\n",
                host: {
                    '[class.disabled]': 'disabled',
                },
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => StepperComponent)),
                        multi: true,
                    },
                ],
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
StepperComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
StepperComponent.propDecorators = {
    min: [{ type: Input }],
    max: [{ type: Input }],
    disabled: [{ type: Input }],
    change: [{ type: Output }],
    _inputNumber: [{ type: ViewChild, args: ['inputNumber', { static: true },] }],
    step: [{ type: Input }]
};
__decorate([
    InputNumber(),
    __metadata("design:type", Object)
], StepperComponent.prototype, "min", void 0);
__decorate([
    InputNumber(),
    __metadata("design:type", Object)
], StepperComponent.prototype, "max", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Object)
], StepperComponent.prototype, "disabled", void 0);
__decorate([
    InputNumber(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], StepperComponent.prototype, "step", null);
if (false) {
    /**
     * @type {?}
     * @private
     */
    StepperComponent.prototype._value;
    /**
     * @type {?}
     * @private
     */
    StepperComponent.prototype.onChange;
    /** @type {?} */
    StepperComponent.prototype._step;
    /** @type {?} */
    StepperComponent.prototype._precisionStep;
    /** @type {?} */
    StepperComponent.prototype._precisionFactor;
    /** @type {?} */
    StepperComponent.prototype._disabledMinus;
    /** @type {?} */
    StepperComponent.prototype._disabledPlus;
    /**
     * 最小值
     * @type {?}
     */
    StepperComponent.prototype.min;
    /**
     * 最大值
     * @type {?}
     */
    StepperComponent.prototype.max;
    /**
     * 禁用
     * @type {?}
     */
    StepperComponent.prototype.disabled;
    /**
     * 变更时回调
     * @type {?}
     */
    StepperComponent.prototype.change;
    /**
     * @type {?}
     * @private
     */
    StepperComponent.prototype._inputNumber;
    /**
     * @type {?}
     * @private
     */
    StepperComponent.prototype.cdr;
}

/**
 * @fileoverview added by tsickle
 * Generated from: stepper.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StepperModule {
}
StepperModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [StepperComponent],
                exports: [StepperComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-stepper.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { StepperComponent, StepperModule };
//# sourceMappingURL=ngx-weui-stepper.js.map
