import { __decorate, __metadata } from 'tslib';
import { Component, ChangeDetectorRef, EventEmitter, Directive, Input, Output, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, NgModule } from '@angular/core';
import { InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * Generated from: bar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BarComponent {
    /**
     * @param {?} cdr
     */
    constructor(cdr) {
        this.cdr = cdr;
        this.tabs = [];
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    add(tab) {
        this.tabs.push(tab);
        tab.active = this.tabs.length === 1 && tab.active !== false;
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    remove(tab) {
        /** @type {?} */
        const index = this.tabs.indexOf(tab);
        if (index === -1 || this.isDestroyed) {
            return;
        }
        // Select a new tab if the tab to be removed is selected and not destroyed
        if (tab.active && this.hasAvailableTabs(index)) {
            /** @type {?} */
            const newActiveIndex = this.getClosestTabIndex(index);
            this.tabs[newActiveIndex].active = true;
        }
        tab.removed.emit(tab);
        this.tabs.splice(index, 1);
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    setActive(tab) {
        tab.active = true;
        tab.select.emit(tab);
    }
    /**
     * @return {?}
     */
    detectChanges() {
        this.cdr.detectChanges();
    }
    /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    getClosestTabIndex(index) {
        /** @type {?} */
        const tabsLength = this.tabs.length;
        if (!tabsLength) {
            return -1;
        }
        for (let step = 1; step <= tabsLength; step += 1) {
            /** @type {?} */
            const prevIndex = index - step;
            /** @type {?} */
            const nextIndex = index + step;
            if (this.tabs[prevIndex] && !this.tabs[prevIndex].disabled) {
                return prevIndex;
            }
            if (this.tabs[nextIndex] && !this.tabs[nextIndex].disabled) {
                return nextIndex;
            }
        }
        return -1;
    }
    /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    hasAvailableTabs(index) {
        /** @type {?} */
        const tabsLength = this.tabs.length;
        if (!tabsLength) {
            return false;
        }
        for (let i = 0; i < tabsLength; i += 1) {
            if (!this.tabs[i].disabled && i !== index) {
                return true;
            }
        }
        return false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.isDestroyed = true;
    }
}
BarComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-bar-component',
                template: ``
            }] }
];
/** @nocollapse */
BarComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
if (false) {
    /** @type {?} */
    BarComponent.prototype.tabs;
    /**
     * @type {?}
     * @protected
     */
    BarComponent.prototype.isDestroyed;
    /**
     * @type {?}
     * @private
     */
    BarComponent.prototype.cdr;
}

/**
 * @fileoverview added by tsickle
 * Generated from: tab.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabDirective {
    /**
     * @param {?} tab
     */
    constructor(tab) {
        this.iconUrl = false;
        /**
         * 当tab激活时触发
         */
        this.select = new EventEmitter();
        /**
         * 当tab无效时触发
         */
        this.deselect = new EventEmitter();
        /**
         * 当tab移除时触发
         */
        this.removed = new EventEmitter();
        this._tabComp = tab;
        this._tabComp.add(this);
    }
    /**
     * 激活
     * @return {?}
     */
    get active() {
        return this._active;
    }
    /**
     * @param {?} active
     * @return {?}
     */
    set active(active) {
        if ((this.disabled && active) || !active) {
            if (!active) {
                this._active = active;
            }
            this.deselect.emit(this);
            return;
        }
        this._active = active;
        this._tabComp.tabs.filter((/**
         * @param {?} t
         * @return {?}
         */
        t => t !== this)).forEach((/**
         * @param {?} tab
         * @return {?}
         */
        tab => (tab.active = false)));
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.iconUrl = /(webp|svg|png|gif|jpg|jpeg|jfif|bmp|dpg)$/i.test(this.icon);
        if (!this.activeIcon) {
            this.activeIcon = this.icon;
        }
        this._tabComp.detectChanges();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._tabComp.remove(this);
    }
}
TabDirective.decorators = [
    { type: Directive, args: [{
                selector: 'weui-tab, [weui-tab]',
                exportAs: 'weuiTab',
                host: {
                    '[class.active]': 'active',
                },
            },] }
];
/** @nocollapse */
TabDirective.ctorParameters = () => [
    { type: BarComponent }
];
TabDirective.propDecorators = {
    heading: [{ type: Input }],
    disabled: [{ type: Input }],
    iconClassName: [{ type: Input }],
    icon: [{ type: Input }],
    activeIcon: [{ type: Input }],
    badge: [{ type: Input }],
    select: [{ type: Output }],
    deselect: [{ type: Output }],
    removed: [{ type: Output }],
    active: [{ type: Input }]
};
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean)
], TabDirective.prototype, "disabled", void 0);
__decorate([
    InputBoolean(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], TabDirective.prototype, "active", null);
if (false) {
    /** @type {?} */
    TabDirective.prototype.iconUrl;
    /**
     * 选项卡名称
     * @type {?}
     */
    TabDirective.prototype.heading;
    /**
     * 是否禁用
     * @type {?}
     */
    TabDirective.prototype.disabled;
    /**
     * Icon类名，一般用于雪碧图
     * @type {?}
     */
    TabDirective.prototype.iconClassName;
    /**
     * icon图标，支持HTML、支持有效图像资源结尾的扩展名URL地址
     * @type {?}
     */
    TabDirective.prototype.icon;
    /**
     * 激活时icon图标，支持HTML、支持有效图像资源结尾的扩展名URL地址
     * @type {?}
     */
    TabDirective.prototype.activeIcon;
    /**
     * 徽章内容，支持数字或圆点
     * @type {?}
     */
    TabDirective.prototype.badge;
    /**
     * 当tab激活时触发
     * @type {?}
     */
    TabDirective.prototype.select;
    /**
     * 当tab无效时触发
     * @type {?}
     */
    TabDirective.prototype.deselect;
    /**
     * 当tab移除时触发
     * @type {?}
     */
    TabDirective.prototype.removed;
    /**
     * @type {?}
     * @protected
     */
    TabDirective.prototype._active;
    /**
     * @type {?}
     * @protected
     */
    TabDirective.prototype._tabComp;
}

/**
 * @fileoverview added by tsickle
 * Generated from: navbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 顶部选项卡
 */
class NavbarComponent extends BarComponent {
}
NavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-navbar',
                exportAs: 'weuiNavbar',
                template: "<div class=\"weui-navbar\">\n  <div\n    class=\"weui-navbar__item\"\n    [ngClass]=\"{ 'weui-bar__item_on': item.active }\"\n    [class.disabled]=\"item.disabled\"\n    *ngFor=\"let item of tabs\"\n    (click)=\"setActive(item)\"\n  >\n    {{ item.heading }}\n  </div>\n</div>\n<div class=\"weui-tab__panel\"><ng-content></ng-content></div>\n",
                providers: [{ provide: BarComponent, useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NavbarComponent)) }],
                host: {
                    '[class.weui-tab]': 'true',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: tabbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 底部选项卡
 */
class TabbarComponent extends BarComponent {
}
TabbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'weui-tabbar',
                exportAs: 'weuiTabbar',
                template: "<div class=\"weui-tab__panel\"><ng-content></ng-content></div>\n<div class=\"weui-tabbar\">\n  <div class=\"weui-tabbar__item\" *ngFor=\"let item of tabs\" [ngClass]=\"{ 'weui-bar__item_on': item.active }\" (click)=\"setActive(item)\">\n    <div style=\"position: relative; display: inline-block;\">\n      <div *ngIf=\"item.iconUrl\" class=\"weui-tabbar__icon\" [ngClass]=\"item.iconClassName\">\n        <img [src]=\"item.active ? item.activeIcon : item.icon\" />\n      </div>\n      <div *ngIf=\"!item.iconUrl\" class=\"weui-tabbar__icon\" [innerHTML]=\"item.active ? item.activeIcon : item.icon\" [ngClass]=\"item.iconClassName\"></div>\n      <span class=\"weui-badge\" style=\"position: absolute; top: -2px; right: -13px;\" *ngIf=\"item.badge && item.badge !== 'dot'\">{{ item.badge }}</span>\n      <span class=\"weui-badge weui-badge_dot\" style=\"position: absolute; top: 0; right: -6px;\" *ngIf=\"item.badge && item.badge === 'dot'\"></span>\n    </div>\n    <p class=\"weui-tabbar__label\">{{ item.heading }}</p>\n  </div>\n</div>\n",
                providers: [{ provide: BarComponent, useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => TabbarComponent)) }],
                host: {
                    '[class.weui-tab]': 'true',
                },
                preserveWhitespaces: false,
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: tab.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COMPONENTS = [TabDirective, NavbarComponent, TabbarComponent, BarComponent];
class TabModule {
}
TabModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: COMPONENTS,
                exports: COMPONENTS,
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-tab.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { BarComponent, NavbarComponent, TabDirective, TabModule, TabbarComponent };
//# sourceMappingURL=ngx-weui-tab.js.map
