import { EventEmitter, OnChanges, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { PickerBaseComponent } from './picker-base.component';
import { PickerData, PickerDateChangeData, PickerDateFormatFullType, PickerDateType, PickerGroupChange } from './picker.types';
/**
 * 日期时间选择器
 */
export declare class DatePickerComponent extends PickerBaseComponent implements OnInit, ControlValueAccessor, OnDestroy, OnChanges {
    /**
     * 日期格式化代码，实际是采用 DatePipe，所有代码内容和它一样
     */
    set format(v: PickerDateFormatFullType);
    private get datePipe();
    private initFlag;
    private _format;
    private readonly _pickerInstance;
    _value: Date;
    _groups: PickerData[][];
    _selected: number[];
    /**
     * 最小时间范围
     * - 当前只限定年月日，暂不包括时间范围
     */
    min: Date;
    /**
     * 最大时间范围
     * - 当前只限定年月日，暂不包括时间范围
     */
    max: Date;
    /**
     * 类型
     * + `date-ym` 年月
     * + `date` 日期
     * + `datetime` 日期&时间（不包括秒）
     * + `time` 时间（不包括秒）
     */
    type: PickerDateType;
    readonly change: EventEmitter<PickerDateChangeData>;
    private onChange;
    private onTouched;
    private genGroups;
    private genDateGroups;
    private genDateTimeGroups;
    private genValueBySelected;
    ngOnDestroy(): void;
    private getFormatDate;
    _onChange(data: PickerDateChangeData): void;
    _onGroupChange(res: PickerGroupChange): void;
    _onCityCancelChange(): void;
    ngOnInit(): void;
    ngOnChanges(): void;
    /** 服务于Service，并无实际意义 */
    _triggerShow(): void;
    _onShow(): void;
    _onHide(): void;
    writeValue(value: Date): void;
    registerOnChange(fn: (_: Date) => {}): void;
    registerOnTouched(fn: () => {}): void;
    setDisabledState(isDisabled: boolean): void;
}
