"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const ast_1 = require("../utils/ast");
const config_1 = require("../utils/devkit-utils/config");
const lib_versions_1 = require("../utils/lib-versions");
const package_1 = require("../utils/package");
const theming_1 = require("./theming");
function default_1(options) {
    return schematics_1.chain([
        options && options.skipPackageJson ? schematics_1.noop() : addWeUIToPackageJson(),
        theming_1.addThemeToAppStyles(options),
        addWeUIRootConfig(options),
        addAnimationRootConfig(options),
        updateAppPage(options),
    ]);
}
exports.default = default_1;
function addWeUIToPackageJson() {
    return (host, context) => {
        package_1.addPackageToPackageJson(host, 'dependencies', 'ngx-weui', lib_versions_1.weuiVersion);
        context.addTask(new tasks_1.NodePackageInstallTask());
        return host;
    };
}
/** Add ngx-weui module to app.module */
function addWeUIRootConfig(options) {
    return (host) => {
        const workspace = config_1.getWorkspace(host);
        const project = config_1.getProjectFromWorkspace(workspace, options.project);
        ast_1.addModuleImportToRootModule(host, 'ButtonModule', 'ngx-weui/button', project);
        return host;
    };
}
/** Add browser animation module to app.module */
function addAnimationRootConfig(options) {
    return (host) => {
        const workspace = config_1.getWorkspace(host);
        const project = config_1.getProjectFromWorkspace(workspace, options.project);
        ast_1.addModuleImportToRootModule(host, 'BrowserAnimationsModule', '@angular/platform-browser/animations', project);
        return host;
    };
}
const appHTML = `<div style="text-align:center; padding: 8px;">
  <h1>
    NGX-WEUI
  </h1>
  <p>
    <a href="https://github.com/weui/weui" target="_blank">WeUI</a> for angular,
    A UI library by WeChat official design team, includes the most useful widgets/modules in mobile web applications.
  </p>
  <div style="margin-top: 16px;">
    <button weui-button>Button</button>
  </div>
</div>
`;
function updateAppPage(options) {
    return (host) => {
        const workspace = config_1.getWorkspace(host);
        const project = config_1.getProjectFromWorkspace(workspace, options.project);
        const appHTMLFile = `${project.sourceRoot}/app/app.component.html`;
        if (host.exists(appHTMLFile)) {
            host.overwrite(appHTMLFile, appHTML);
        }
        return host;
    };
}
//# sourceMappingURL=index.js.map