"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addThemeToAppStyles = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const ast_1 = require("../utils/ast");
const change_1 = require("../utils/devkit-utils/change");
const config_1 = require("../utils/devkit-utils/config");
const custom_theme_1 = require("./custom-theme");
function addThemeToAppStyles(options) {
    // tslint:disable-next-line: only-arrow-functions
    return function (host) {
        const workspace = config_1.getWorkspace(host);
        const project = config_1.getProjectFromWorkspace(workspace, options.project);
        // Because the build setup for the Angular CLI can be changed so dramatically, we can't know
        // where to generate anything if the project is not using the default config for build and test.
        assertDefaultProjectConfig(project);
        const stylesPath = ast_1.getStylesPath(host, project);
        if (stylesPath.endsWith('.less')) {
            console.error(`Your project is not using less styles, current file: ${stylesPath}`);
        }
        const buffer = host.read(stylesPath);
        if (buffer) {
            const insertion = new change_1.InsertChange(stylesPath, 0, custom_theme_1.createCustomTheme(project));
            const recorder = host.beginUpdate(stylesPath);
            recorder.insertLeft(insertion.pos, insertion.toAdd);
            host.commitUpdate(recorder);
        }
        else {
            console.warn(`Skipped insert style; could not find file: ${stylesPath}`);
        }
        return host;
    };
}
exports.addThemeToAppStyles = addThemeToAppStyles;
/** Throws if the project is not using the default build and test config. */
function assertDefaultProjectConfig(project) {
    if (!isProjectUsingDefaultConfig(project)) {
        throw new schematics_1.SchematicsException('Your project is not using the default configuration for ' +
            'build and test. The Angular Material schematics can only be used with the default ' +
            'configuration');
    }
}
/** Gets whether the Angular CLI project is using the default build configuration. */
function isProjectUsingDefaultConfig(project) {
    const defaultBuilder = '@angular-devkit/build-angular:browser';
    return (project.architect &&
        project.architect.build &&
        project.architect.build.builder === defaultBuilder &&
        project.architect.test &&
        project.architect.build.builder === defaultBuilder);
}
//# sourceMappingURL=theming.js.map